====================
Django User Accounts
====================

.. image:: http://slack.pinaxproject.com/badge.svg
   :target: http://slack.pinaxproject.com/

.. image:: https://img.shields.io/travis/pinax/django-user-accounts.svg
    :target: https://travis-ci.org/pinax/django-user-accounts

.. image:: https://img.shields.io/coveralls/pinax/django-user-accounts.svg
    :target: https://coveralls.io/r/pinax/django-user-accounts

.. image:: https://img.shields.io/pypi/dm/django-user-accounts.svg
    :target:  https://pypi.python.org/pypi/django-user-accounts/

.. image:: https://img.shields.io/pypi/v/django-user-accounts.svg
    :target:  https://pypi.python.org/pypi/django-user-accounts/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target:  https://pypi.python.org/pypi/django-user-accounts/


Pinax
-------

Pinax is an open-source platform built on the Django Web Framework. It is an ecosystem of reusable Django apps, themes, and starter project templates.
This collection can be found at http://pinaxproject.com.

This app was developed as part of the Pinax ecosystem but is just a Django app and can be used independently of other Pinax apps.


django-user-accounts
-------------------------

``django-user-accounts`` provides a Django project with a very extensible infrastructure for dealing
with user accounts.


Features
----------

* Functionality for:

  - Log in (email or username authentication)
  - Sign up
  - Email confirmation
  - Signup tokens for private betas
  - Password reset
  - Password expiration
  - Account management (update account settings and change password)
  - Account deletion

* Extensible class-based views and hooksets
* Custom ``User`` model support


Requirements
--------------

* Django 1.8, 1.9, or 1.10
* Python 2.7, 3.3, 3.4 or 3.5
* django-appconf (included in ``install_requires``)
* pytz (included in ``install_requires``)


Documentation
----------------

See http://django-user-accounts.readthedocs.org/ for the ``django-user-accounts`` documentation.
We recently did a Pinax Hangout on ``django-user-accounts``, you can read the recap blog post and find the video here http://blog.pinaxproject.com/2015/10/12/recap-september-pinax-hangout/.

The Pinax documentation is available at http://pinaxproject.com/pinax/. If you would like to help us improve our documentation or write more documentation, please join our Slack team and let us know!


Contribute
----------------

See this blog post http://blog.pinaxproject.com/2016/02/26/recap-february-pinax-hangout/ including a video, or our How to Contribute (http://pinaxproject.com/pinax/how_to_contribute/) section for an overview on how contributing to Pinax works. For concrete contribution ideas, please see our Ways to Contribute/What We Need Help With (http://pinaxproject.com/pinax/ways_to_contribute/) section.

In case of any questions we recommend you join our Pinax Slack team (http://slack.pinaxproject.com) and ping us there instead of creating an issue on GitHub. Creating issues on GitHub is of course also valid but we are usually able to help you faster if you ping us in Slack.

We also highly recommend reading our Open Source and Self-Care blog post (http://blog.pinaxproject.com/2016/01/19/open-source-and-self-care/).


Code of Conduct
-----------------

In order to foster a kind, inclusive, and harassment-free community, the Pinax Project has a code of conduct, which can be found here  http://pinaxproject.com/pinax/code_of_conduct/.
We ask you to treat everyone as a smart human programmer that shares an interest in Python, Django, and Pinax with you.



Pinax Project Blog and Twitter
--------------------------------

For updates and news regarding the Pinax Project, please follow us on Twitter at @pinaxproject and check out our blog http://blog.pinaxproject.com.
